==> zio-aws-rds_2.13-5.19.33.1-sources.jar: zio/aws/rds/model/ClusterPendingModifiedValues.scala <==
package zio.aws.rds.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.rds.model.primitives.{IntegerOptional, BooleanOptional}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ClusterPendingModifiedValues(
    pendingCloudwatchLogsExports: Optional[
      zio.aws.rds.model.PendingCloudwatchLogsExports
    ] = Optional.Absent,
    dbClusterIdentifier: Optional[String] = Optional.Absent,
    masterUserPassword: Optional[String] = Optional.Absent,
    iamDatabaseAuthenticationEnabled: Optional[BooleanOptional] =
      Optional.Absent,
    engineVersion: Optional[String] = Optional.Absent,
    backupRetentionPeriod: Optional[IntegerOptional] = Optional.Absent,
    allocatedStorage: Optional[IntegerOptional] = Optional.Absent,
    iops: Optional[IntegerOptional] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues = {
    import ClusterPendingModifiedValues.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
      .builder()
      .optionallyWith(
        pendingCloudwatchLogsExports.map(value => value.buildAwsValue())
      )(_.pendingCloudwatchLogsExports)
      .optionallyWith(
        dbClusterIdentifier.map(value => value: java.lang.String)
      )(_.dbClusterIdentifier)
      .optionallyWith(masterUserPassword.map(value => value: java.lang.String))(
        _.masterUserPassword
      )
      .optionallyWith(
        iamDatabaseAuthenticationEnabled.map(value => value: java.lang.Boolean)
      )(_.iamDatabaseAuthenticationEnabled)
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .optionallyWith(backupRetentionPeriod.map(value => value: Integer))(
        _.backupRetentionPeriod
      )
      .optionallyWith(allocatedStorage.map(value => value: Integer))(
        _.allocatedStorage
      )
      .optionallyWith(iops.map(value => value: Integer))(_.iops)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ClusterPendingModifiedValues.ReadOnly =
    zio.aws.rds.model.ClusterPendingModifiedValues.wrap(buildAwsValue())
}
object ClusterPendingModifiedValues {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ClusterPendingModifiedValues =
      zio.aws.rds.model.ClusterPendingModifiedValues(
        pendingCloudwatchLogsExports.map(value => value.asEditable),
        dbClusterIdentifier.map(value => value),
        masterUserPassword.map(value => value),
        iamDatabaseAuthenticationEnabled.map(value => value),
        engineVersion.map(value => value),
        backupRetentionPeriod.map(value => value),
        allocatedStorage.map(value => value),
        iops.map(value => value)
      )
    def pendingCloudwatchLogsExports
        : Optional[zio.aws.rds.model.PendingCloudwatchLogsExports.ReadOnly]
    def dbClusterIdentifier: Optional[String]
    def masterUserPassword: Optional[String]
    def iamDatabaseAuthenticationEnabled: Optional[BooleanOptional]
    def engineVersion: Optional[String]
    def backupRetentionPeriod: Optional[IntegerOptional]
    def allocatedStorage: Optional[IntegerOptional]
    def iops: Optional[IntegerOptional]
    def getPendingCloudwatchLogsExports: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.PendingCloudwatchLogsExports.ReadOnly
    ] = AwsError.unwrapOptionField(
      "pendingCloudwatchLogsExports",
      pendingCloudwatchLogsExports
    )
    def getDbClusterIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbClusterIdentifier", dbClusterIdentifier)
    def getMasterUserPassword: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("masterUserPassword", masterUserPassword)
    def getIamDatabaseAuthenticationEnabled
        : ZIO[Any, AwsError, BooleanOptional] = AwsError.unwrapOptionField(
      "iamDatabaseAuthenticationEnabled",
      iamDatabaseAuthenticationEnabled
    )
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getBackupRetentionPeriod: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("backupRetentionPeriod", backupRetentionPeriod)
    def getAllocatedStorage: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("allocatedStorage", allocatedStorage)
    def getIops: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("iops", iops)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
  ) extends zio.aws.rds.model.ClusterPendingModifiedValues.ReadOnly {
    override val pendingCloudwatchLogsExports
        : Optional[zio.aws.rds.model.PendingCloudwatchLogsExports.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pendingCloudwatchLogsExports())
        .map(value =>
          zio.aws.rds.model.PendingCloudwatchLogsExports.wrap(value)
        )
    override val dbClusterIdentifier: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.dbClusterIdentifier())
      .map(value => value: String)
    override val masterUserPassword: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.masterUserPassword())
      .map(value => value: String)
    override val iamDatabaseAuthenticationEnabled: Optional[BooleanOptional] =
      zio.aws.core.internal
        .optionalFromNullable(impl.iamDatabaseAuthenticationEnabled())
        .map(value => value: BooleanOptional)
    override val engineVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.engineVersion())
      .map(value => value: String)
    override val backupRetentionPeriod: Optional[IntegerOptional] =
      zio.aws.core.internal
        .optionalFromNullable(impl.backupRetentionPeriod())
        .map(value => value: IntegerOptional)
    override val allocatedStorage: Optional[IntegerOptional] =
      zio.aws.core.internal
        .optionalFromNullable(impl.allocatedStorage())
        .map(value => value: IntegerOptional)
    override val iops: Optional[IntegerOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.iops())
      .map(value => value: IntegerOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
  ): zio.aws.rds.model.ClusterPendingModifiedValues.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.104.5-sources.jar: zio/aws/rds/model/ClusterPendingModifiedValues.scala <==
package zio.aws.rds.model
import zio.aws.rds.model.primitives.BooleanOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ClusterPendingModifiedValues(
    pendingCloudwatchLogsExports: scala.Option[
      zio.aws.rds.model.PendingCloudwatchLogsExports
    ] = None,
    dbClusterIdentifier: scala.Option[String] = None,
    masterUserPassword: scala.Option[String] = None,
    iamDatabaseAuthenticationEnabled: scala.Option[BooleanOptional] = None,
    engineVersion: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues = {
    import ClusterPendingModifiedValues.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
      .builder()
      .optionallyWith(
        pendingCloudwatchLogsExports.map(value => value.buildAwsValue())
      )(_.pendingCloudwatchLogsExports)
      .optionallyWith(
        dbClusterIdentifier.map(value => value: java.lang.String)
      )(_.dbClusterIdentifier)
      .optionallyWith(masterUserPassword.map(value => value: java.lang.String))(
        _.masterUserPassword
      )
      .optionallyWith(
        iamDatabaseAuthenticationEnabled.map(value =>
          BooleanOptional.unwrap(value): java.lang.Boolean
        )
      )(_.iamDatabaseAuthenticationEnabled)
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ClusterPendingModifiedValues.ReadOnly =
    zio.aws.rds.model.ClusterPendingModifiedValues.wrap(buildAwsValue())
}
object ClusterPendingModifiedValues {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ClusterPendingModifiedValues =
      zio.aws.rds.model.ClusterPendingModifiedValues(
        pendingCloudwatchLogsExports.map(value => value.asEditable),
        dbClusterIdentifier.map(value => value),
        masterUserPassword.map(value => value),
        iamDatabaseAuthenticationEnabled.map(value => value),
        engineVersion.map(value => value)
      )
    def pendingCloudwatchLogsExports
        : scala.Option[zio.aws.rds.model.PendingCloudwatchLogsExports.ReadOnly]
    def dbClusterIdentifier: scala.Option[String]
    def masterUserPassword: scala.Option[String]
    def iamDatabaseAuthenticationEnabled: scala.Option[BooleanOptional]
    def engineVersion: scala.Option[String]
    def getPendingCloudwatchLogsExports: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.PendingCloudwatchLogsExports.ReadOnly
    ] = AwsError.unwrapOptionField(
      "pendingCloudwatchLogsExports",
      pendingCloudwatchLogsExports
    )
    def getDbClusterIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbClusterIdentifier", dbClusterIdentifier)
    def getMasterUserPassword: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("masterUserPassword", masterUserPassword)
    def getIamDatabaseAuthenticationEnabled
        : ZIO[Any, AwsError, BooleanOptional] = AwsError.unwrapOptionField(
      "iamDatabaseAuthenticationEnabled",
      iamDatabaseAuthenticationEnabled
    )
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
  ) extends zio.aws.rds.model.ClusterPendingModifiedValues.ReadOnly {
    override val pendingCloudwatchLogsExports: scala.Option[
      zio.aws.rds.model.PendingCloudwatchLogsExports.ReadOnly
    ] = scala
      .Option(impl.pendingCloudwatchLogsExports())
      .map(value => zio.aws.rds.model.PendingCloudwatchLogsExports.wrap(value))
    override val dbClusterIdentifier: scala.Option[String] =
      scala.Option(impl.dbClusterIdentifier()).map(value => value: String)
    override val masterUserPassword: scala.Option[String] =
      scala.Option(impl.masterUserPassword()).map(value => value: String)
    override val iamDatabaseAuthenticationEnabled
        : scala.Option[BooleanOptional] = scala
      .Option(impl.iamDatabaseAuthenticationEnabled())
      .map(value => zio.aws.rds.model.primitives.BooleanOptional(value))
    override val engineVersion: scala.Option[String] =
      scala.Option(impl.engineVersion()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ClusterPendingModifiedValues
  ): zio.aws.rds.model.ClusterPendingModifiedValues.ReadOnly = new Wrapper(impl)
}
